#!/usr/bin/python
# -*- coding: utf-8 -*-
# 
#   FILE: FitTweetsDB.py
#   DATE: December, 2012
#   Author: David W. McDonald
#
#   An object for managing the fitness tweet collection
#
#   Copyright by Author. All rights reserved. Not for reuse without
#   express permissions.
#
#
from hcde.data.db.base.TweetsDB import TweetsDB
from hcde.data.db.fitness.FitTweetObj import FitTweetObj
from sqlalchemy.orm import mapper, class_mapper
from sqlalchemy.orm.exc import UnmappedClassError
import sys

class FitTweetsDB(TweetsDB):
    def __init__(self, config=None):
        TweetsDB.__init__(self, config=config)

        try:
            self.tweet_mapper = class_mapper(FitTweetObj)
        except UnmappedClassError:
            self.tweet_mapper = mapper(FitTweetObj,self.tweet_table)


##
# New object creation routines
##
    ## Create "tweet" objects and records
    def new_tweet_table_item(self, rec=None):
        nto = FitTweetObj()
        if( rec ):
            return nto.from_dict(rec)
        return nto

    def tweet_table_item_to_dict(self, tto=None):
        rec = {}
        if( tto ):
            rec = tto.to_dict()
        return rec

##
# straight forward query types
##
    ##
    ## Query the tweet table
    ##
    def query_tweet_table_by_tweet_id(self, tid):
        t = self.session.query(FitTweetObj).filter(FitTweetObj.tweet_id==tid).all()
        return t

    def query_tweet_table_by_username(self, uname=None, start_date=None, end_date=None):
        q = self._tweet_table_date_range(start_date=start_date, end_date=end_date)
        q = q.filter(FitTweetObj.from_user==uname)
        tlist = q.all()
        return tlist

    def query_tweet_table_by_user_id(self, uid=None, start_date=None, end_date=None):
        q = self._tweet_table_date_range(start_date=start_date, end_date=end_date)
        q = q.filter(FitTweetObj.from_user_id==uid)
        tlist = q.all()
        return tlist

    def query_tweet_table_by_tweet_substr(self, substr=None, start_date=None, end_date=None):
        qtext = "%"+substr+"%"
        q = self._tweet_table_date_range(start_date=start_date, end_date=end_date)
        q = q.filter(FitTweetObj.tweet_text.like(qtext))
        tlist = q.all()
        return tlist

    def query_tweet_table_by_date_range(self, start_date=None, end_date=None, in_order=True):
        q = self._tweet_table_date_range(start_date=start_date, end_date=end_date)
        if( in_order ):
            q = q.order_by(FitTweetObj.created_at)
        tlist = q.all()
        return tlist

    def _tweet_table_date_range(self, start_date=None, end_date=None):
        query = self.session.query(FitTweetObj)
        if( start_date and end_date ):
            query = query.filter(FitTweetObj.created_at>=start_date)
            query = query.filter(FitTweetObj.created_at<end_date)
        elif( start_date ):
            query = query.filter(FitTweetObj.created_at>=start_date)
        elif( end_date ):
            query = query.filter(FitTweetObj.created_at<end_date)
        else:
            pass
        return query

