
##
##  Table setup
##
BEGIN;
USE tweet_ha_act;
CREATE TABLE `twitter_tweets` (
  `rid` BIGINT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY,
  `tweet_id` BIGINT UNSIGNED DEFAULT NULL,
  `tweet_id_str` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `from_user_id` BIGINT UNSIGNED DEFAULT NULL,
  `from_user` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `from_user_name` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `query_source` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `lat` DECIMAL(25,16) DEFAULT NULL,
  `lon` DECIMAL(25,16) DEFAULT NULL,
  `tweet_text` VARCHAR(256) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL 
) ENGINE=MyISAM DEFAULT CHARACTER SET 'utf8' COLLATE 'utf8_general_ci';
ALTER TABLE `twitter_tweets` ADD INDEX `tweet_index` (`tweet_id`);
ALTER TABLE `twitter_tweets` ADD INDEX `user_index` (`from_user`);
ALTER TABLE `twitter_tweets` ADD INDEX `id_index` (`from_user_id`);
ALTER TABLE `twitter_tweets` ADD INDEX `date_index` (`created_at`);
ALTER TABLE `twitter_tweets` ADD INDEX `source_index` (`query_source`);

CREATE TABLE `twitter_users` (
  `rid` BIGINT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY,
  `user_name` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `screen_name` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `user_id` BIGINT UNSIGNED DEFAULT NULL,
  `join_dt` datetime DEFAULT NULL,
  `verified` BOOLEAN DEFAULT FALSE,
  `geo_enabled` BOOLEAN DEFAULT FALSE,
  `location` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `lang` VARCHAR(8) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `time_zone` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `url` VARCHAR(256) CHARACTER SET 'utf8' DEFAULT NULL,
  `description` VARCHAR(256) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL
) ENGINE=MyISAM DEFAULT CHARACTER SET 'utf8' COLLATE 'utf8_general_ci';
ALTER TABLE `twitter_users` ADD INDEX `name_index` (`user_name`);
ALTER TABLE `twitter_users` ADD INDEX `screen_index` (`screen_name`);
ALTER TABLE `twitter_users` ADD INDEX `id_index` (`user_id`);
  
CREATE TABLE `twitter_user_meta` (
  `rid` BIGINT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY,
  `user_name` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `screen_name` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `user_id` BIGINT UNSIGNED DEFAULT NULL,
  `friend_count` BIGINT UNSIGNED DEFAULT NULL,
  `follower_count` BIGINT UNSIGNED DEFAULT NULL,
  `profile_collect_dt` datetime DEFAULT NULL,
  `friend_collect_dt` datetime DEFAULT NULL,
  `friend_collect_resp` VARCHAR(32) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `follower_collect_dt` datetime DEFAULT NULL,
  `follower_collect_resp` VARCHAR(32) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL
) ENGINE=MyISAM DEFAULT CHARACTER SET 'utf8' COLLATE 'utf8_general_ci';
ALTER TABLE `twitter_user_meta` ADD INDEX `name_index` (`user_name`);
ALTER TABLE `twitter_user_meta` ADD INDEX `screen_index` (`screen_name`);
ALTER TABLE `twitter_user_meta` ADD INDEX `id_index` (`user_id`);

CREATE TABLE `twitter_friends` (
  `rid` BIGINT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY,
  `user` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `friend` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `user_id` BIGINT UNSIGNED DEFAULT NULL,
  `friend_id` BIGINT UNSIGNED DEFAULT NULL,
  `user_local_id` BIGINT UNSIGNED DEFAULT NULL,
  `friend_local_id` BIGINT UNSIGNED DEFAULT NULL
) ENGINE=MyISAM DEFAULT CHARACTER SET 'utf8' COLLATE 'utf8_general_ci';
ALTER TABLE `twitter_friends` ADD INDEX `user_index` (`user`);
ALTER TABLE `twitter_friends` ADD INDEX `user_id_index` (`user_id`);
ALTER TABLE `twitter_friends` ADD INDEX `user_local_index` (`user_local_id`);
ALTER TABLE `twitter_friends` ADD INDEX `friend_index` (`friend_id`);

CREATE TABLE `twitter_followers` (
  `rid` BIGINT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY,
  `user` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `follower` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_general_ci' DEFAULT NULL,
  `user_id` BIGINT UNSIGNED DEFAULT NULL,
  `follower_id` BIGINT UNSIGNED DEFAULT NULL,
  `user_local_id` BIGINT UNSIGNED DEFAULT NULL,
  `follower_local_id` BIGINT UNSIGNED DEFAULT NULL
) ENGINE=MyISAM DEFAULT CHARACTER SET 'utf8' COLLATE 'utf8_general_ci';
ALTER TABLE `twitter_followers` ADD INDEX `user_index` (`user`);
ALTER TABLE `twitter_followers` ADD INDEX `user_id_index` (`user_id`);
ALTER TABLE `twitter_followers` ADD INDEX `user_local_index` (`user_local_id`);
ALTER TABLE `twitter_followers` ADD INDEX `follower_index` (`follower_id`);
COMMIT;

###
###  Finding Tweets
###
###  finding if the substring "injury" is in the tweet
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE tweet_text LIKE "%injury%"
###  finding tweets with a specific hashtag
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE tweet_text LIKE "%#fitness%"
###  finding tweets with a URL
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE tweet_text LIKE "%http://%"
###  finding tweets that look like a retweet
#SELECT * FROM tweet_ha_act.twitter_tweets
#WHERE (tweet_text LIKE "%RT @%") OR (tweet_text LIKE "%VIA @%")
#OR (tweet_text LIKE "%Rt @%") OR (tweet_text LIKE "%Via @%")
#OR (tweet_text LIKE "%rt @%") OR (tweet_text LIKE "%via @%")
###  finding specific user mentions
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE tweet_text LIKE "%@jennycraig%"
###  tweets from a specific user - user name (from_user) is a string
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE from_user="JennyCraig"
###  tweets from a specific user - user id (from_user_id) is a number
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE from_user_id=275213754
###  tweets that look to have location info
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE (not lat=0.0) OR (not lon=0.0)
###  tweets that were created between 2012-04-10 00:00:00 and 2012-04-12 00:00:00
###  dates are strings expressed as YYYYMMDDHHMMSS
#SELECT * FROM tweet_ha_act.twitter_tweets WHERE (created_at>='20120410000000') 
#    AND (created_at<'20120412000000')
###
###  
###  Find the frequent twitterers, with 100 or more tweets
###  in the dataset
#SELECT from_user,from_user_name,from_user_id,lat,lon,
#COUNT(from_user) AS tweet_frequency
#FROM tweet_ha_act.twitter_tweets
#GROUP BY from_user HAVING (COUNT(from_user)>=100)
#ORDER BY tweet_frequency DESC
#
###  
###  Find stuff that might be from a news agency
###
#SELECT * FROM tweet_ha_act.twitter_tweets 
#WHERE (from_user_name LIKE "%news%") OR (from_user LIKE "%news%") 
#OR (from_user_name LIKE "%press%") OR (from_user LIKE "%press%")
#
#SELECT rid,from_user,from_user_name, COUNT(from_user) AS occurrences
#FROM tweet_ha_act.twitter_tweets 
#WHERE (from_user_name LIKE "%news%") OR (from_user LIKE "%news%") 
#OR (from_user_name LIKE "%press%") OR (from_user LIKE "%press%")
#GROUP BY from_user HAVING (COUNT(from_user)>0)
#
###
###  Finding duplicate tweets in the tweet table
###
#SELECT tweet_id, COUNT(tweet_id) AS occurrences
#FROM tweet_ha_act.twitter_tweets
#GROUP BY tweet_id HAVING ( COUNT(tweet_id)>1 )
#
###
###  Finding duplicate users in the user table
###
###  This user_id one generates a few similar
#SELECT user_id,user_name,screen_name, COUNT(user_id) AS occurrences
#FROM tweet_ha_act.twitter_users
#GROUP BY user_id HAVING (COUNT(user_id)>1)
#
###  Query by user_name is unique
#SELECT user_name,screen_name,user_id, COUNT(user_name) AS occurrences
#FROM tweet_ha_act.twitter_users
#GROUP BY user_name HAVING (COUNT(user_name)>1)
#
###
### Finding the users who have and have not had profile downloaded
#SELECT * FROM tweet_ha_act.twitter_users where join_dt>"20010101000000"
#SELECT * FROM tweet_ha_act.twitter_users where join_dt<="20010101000000"
#SELECT rid,user_id,user_name,screen_name FROM tweet_me.twitter_users where join_dt<="20010101000000"
